sourcefiles

package
v0.2.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 14, 2026 License: MIT Imports: 4 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func IsFrameworkGenerated

func IsFrameworkGenerated(filename string) bool

IsFrameworkGenerated reports whether the file is Vango-owned generated glue that should not participate in source-of-truth analysis passes.

func ParseForAnalysis

func ParseForAnalysis(fset *token.FileSet, filename string, src []byte) (*ast.File, error)

ParseForAnalysis parses handwritten source normally, but reduces Vango-owned generated glue to its package clause so go/packages can still type-check the surrounding package without treating generated artifacts as analyzable source.

Types

This section is empty.

Jump to