Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Info ¶
type Info struct {
Kind Kind `json:"kind,omitempty"`
Platform Platform `json:"platform,omitempty"`
Topology Topology `json:"topology,omitempty"`
AppVersion string `json:"appVersion,omitempty"`
BuildChannel string `json:"buildChannel,omitempty"`
WindowID string `json:"windowID,omitempty"`
Capabilities map[string]bool `json:"capabilities,omitempty"`
}
Info describes the connected surface.
The zero value normalizes to the default browser/web surface.
func DesktopMacOS ¶
DesktopMacOS returns a normalized macOS desktop surface descriptor.
func DesktopMacOSWithTopology ¶
func DesktopMacOSWithTopology(topology Topology, windowID, appVersion, buildChannel string, capabilities map[string]bool) Info
DesktopMacOSWithTopology returns a normalized macOS desktop surface descriptor for the requested runtime topology.
func (Info) CapabilityNames ¶
CapabilityNames returns the enabled capability names in deterministic order.
func (Info) HasCapability ¶
HasCapability reports whether the named capability is advertised.
Click to show internal directories.
Click to hide internal directories.